Crate ration

Ration

A simple, easy-to-use, shared memory library.

Getting Started

It’s best to start by looking through the examples directory.

Note on allocating/opening paths.

If the path you provide to alloc or open for some data type, ration will attempt to place your data structure into /dev/shm/.

Re-exports

pub use array::*;
pub use block::*;

Modules

array
Shared Memory Array
block
Shared Memory Block

Enums

Error

Type Aliases

Result